@@ -164,7 +164,8 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
                     dvbl = DataVarsBuilderLinux(systemRoot=distr_dn)
                     dvbl['cl_update_binhost_recheck_set'] = \
                         self.Get('update.cl_update_binhost_recheck_set')
-                    if source:
+                    if self.Get('cl_action') not in (
+                            Actions.Update, Actions.ChangeProfile):
                         dvbl.cache['cl_update_binhost_data'] = [[]]
                     dvbl.prepare_all()
                     return dvbl
